@@ -3,9 +3,9 @@ from inspect import stack
 
 import click
 
-from com.enovation.helper.click.df_load import load_csv, load_xls
-from com.enovation.helper.click.df_write import to_stdout, to_xlsx
-from com.enovation.helper.click.df_modify import rename_columns, cleanse_null_values
+from com.enovation.helper.click.df_load import df_load_csv, df_load_xls
+from com.enovation.helper.click.df_write import df_to_stdout, df_to_xlsx
+from com.enovation.helper.click.df_modify import df_rename_columns, df_cleanse_null, df_compress
 from com.enovation.toolbox.predictability.click.dp_compute import dp_compute_date_predictability
 from com.enovation.toolbox.predictability.click.dp_demo import dp_demo_date_predictability
 from com.enovation.toolbox.predictability.click.dp_persist \
@@ -17,15 +17,14 @@ _logger: logging.Logger = logging.getLogger(__name__)
 
 
 @click.group(chain=True)
+@click.pass_context
 @click.option(
     '--verbose/--no-verbose', type=bool, default=None,
     help='Level of logging verbosity: INFO (--verbose), WARNING (default) or ERROR (--no-verbose).',
 )
-@click.pass_context
 def enov(ctx_context, verbose):
-    """
-    The click application to call com.enovation modules...
-    """
+
+    _logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is called")
 
     if verbose is True:
         click.echo("logging: INFO")
@@ -36,37 +35,50 @@ def enov(ctx_context, verbose):
     else:
         click.echo("logging: WARNING")
         logging.basicConfig(level="WARNING")
-
-    _logger.debug(f"Function enov called.")
     _logger.info(f"Welcome!")
 
-    _logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is called")
-
     # Ensure that ctx_context.obj exists and is a dict (in case `cli()` is called
     # by means other than the `if` block below)
     # This is effectively the context, that is shared across commands
-    ctx_context.ensure_object(dict)
+    if ctx_context.obj:
+        pass
+    else:
+        _logger.debug(f"We call function ctx_context.ensure_object(dict)")
+        ctx_context.ensure_object(dict)
 
     _logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is returning")
 
 
 # com.enovation.helper.click.df_load
-enov.add_command(load_csv)
-enov.add_command(load_xls)
+# noinspection PyTypeChecker
+enov.add_command(df_load_csv)
+# noinspection PyTypeChecker
+enov.add_command(df_load_xls)
 
 # com.enovation.helper.click.df_write
-enov.add_command(to_stdout)
-enov.add_command(to_xlsx)
+# noinspection PyTypeChecker
+enov.add_command(df_to_stdout)
+# noinspection PyTypeChecker
+enov.add_command(df_to_xlsx)
 
 # com.enovation.helper.click.df_modify
-enov.add_command(rename_columns)
-enov.add_command(cleanse_null_values)
+# noinspection PyTypeChecker
+enov.add_command(df_rename_columns)
+# noinspection PyTypeChecker
+enov.add_command(df_cleanse_null)
+# noinspection PyTypeChecker
+enov.add_command(df_compress)
 
 # com.enovation.toolbox.predictability.click - Date Predictability
+# noinspection PyTypeChecker
 enov.add_command(dp_compute_date_predictability)
+# noinspection PyTypeChecker
 enov.add_command(dp_write_bean_date_predictability)
+# noinspection PyTypeChecker
 enov.add_command(dp_load_bean_date_predictability)
+# noinspection PyTypeChecker
 enov.add_command(dp_graph_to_dash_date_predictability)
+# noinspection PyTypeChecker
 enov.add_command(dp_demo_date_predictability)
 
 
