@@ -453,7 +453,8 @@ class DatePredictabilityComputer:
             str_column_label__date: str = str__input__column_label__date,
             str_column_label__measure: str = str__input__column_label__measure,
     ) -> float:
-        self._logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is called.")
+        # Too many logs:
+        # self._logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is called.")
 
         dt_the_last_date: datetime = df_measures[self.str__input__column_label__date].max()
 
@@ -499,7 +500,8 @@ class DatePredictabilityComputer:
             a_measures_predictabilities.sum() \
             / len(a_measures_predictabilities)
 
-        self._logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is returning.")
+        # Too many logs:
+        # self._logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is returning.")
 
         return f_the_return
 
